"""
The pythonbible-parser library.

pythonbible-parser is a Python library for parsing Bible texts in various formats
and convert them into a format for easy and efficient use in Python.
"""

from __future__ import annotations

__version__ = "0.0.4"
